summaryrefslogtreecommitdiff
path: root/lib/ping.php
diff options
context:
space:
mode:
authorEvan Prodromou <evan@controlyourself.ca>2009-08-25 18:12:20 -0400
committerEvan Prodromou <evan@controlyourself.ca>2009-08-25 18:12:20 -0400
commitc8b8f07af14ad2ce9d0c0267962dd3bbf6473a4b (patch)
tree2ed665ca0639c845f425c671fdffccc01e6ddc3a /lib/ping.php
parentd0baab6978f1959382d568d26cc9f8f552a7b764 (diff)
change Laconica and Control Yourself to StatusNet in PHP files
Diffstat (limited to 'lib/ping.php')
-rw-r--r--lib/ping.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/ping.php b/lib/ping.php
index d26c73417..29cb25167 100644
--- a/lib/ping.php
+++ b/lib/ping.php
@@ -1,7 +1,7 @@
<?php
/*
* Laconica - a distributed open-source microblogging tool
* Copyright (C) 2009, Control Yourself, Inc.
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
@@ -47,7 +47,7 @@ function ping_broadcast_notice($notice) {
$context = stream_context_create(array('http' => array('method' => "POST",
'header' =>
"Content-Type: text/xml\r\n".
- "User-Agent: Laconica/".LACONICA_VERSION."\r\n",
+ "User-Agent: StatusNet/".LACONICA_VERSION."\r\n",
'content' => $req)));
$file = file_get_contents($notify_url, false, $context);
@@ -81,11 +81,11 @@ function ping_broadcast_notice($notice) {
if ($type === 'get') {
$result = $fetcher->get($notify_url . '?' . http_build_query($args),
- array('User-Agent: Laconica/'.LACONICA_VERSION));
+ array('User-Agent: StatusNet/'.LACONICA_VERSION));
} else {
$result = $fetcher->post($notify_url,
http_build_query($args),
- array('User-Agent: Laconica/'.LACONICA_VERSION));
+ array('User-Agent: StatusNet/'.LACONICA_VERSION));
}
if ($result->status != '200') {
common_log(LOG_WARNING,
@@ -1,7 +1,7 @@
<?php
/*
- * Laconica - a distributed open-source microblogging tool
- * Copyright (C) 2009, Control Yourself, Inc.
+ * StatusNet - a distributed open-source microblogging tool
+ * Copyright (C) 2009, StatusNet, Inc.
*
* This program is free software: you can redistribute it and/or modify